
# Type: timepoint


a point in time

URI: [biolink:timepoint](https://w3id.org/biolink/vocab/timepoint)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>OPT</sub> [TimeType](types/TimeType.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [GeographicLocationAtTime](GeographicLocationAtTime.md)
